﻿using Rhino;
using Rhino.Collections;
using Rhino.Commands;
using Rhino.DocObjects;
using Rhino.Geometry;
using Rhino.Input;
using Rhino.Input.Custom;
using Rhino.UI;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Runtime.InteropServices;
using System.Text;
using System.Threading.Tasks;

namespace RhinoTestUserData
{
	[Guid("9EC4E9FA-102B-422C-9728-07A9536F1CDB")]
	public class UDGetUserDataCmd : Command
	{
		public static UDGetUserDataCmd Instance { get; protected set; }
		public override string EnglishName { get { return "UDGetUserData"; } }

		public UDGetUserDataCmd()
		{
			UDGetUserDataCmd.Instance = this;
		}

		protected override Result RunCommand(RhinoDoc doc, RunMode mode)
		{
			GetObject getObj = new GetObject();
			getObj.SetCommandPrompt("Select an object to get user data from");
			if (getObj.Get() != GetResult.Object)
				return Result.Cancel;

			ObjRef selectedObjRef = getObj.Object(0);
			RhinoObject selectedObj = selectedObjRef.Object();

			if (!selectedObj.Geometry.UserDictionary.ContainsKey("TestUserData.BBoxCenter"))
			{
				Dialogs.ShowMessage("Object contains no user data!", "Test User Data", ShowMessageButton.OK, ShowMessageIcon.Warning);
				return Result.Failure;
			}

			Point3d readPoint = selectedObj.Geometry.UserDictionary.GetPoint3d("TestUserData.BBoxCenter", Point3d.Unset);
			if (readPoint != Point3d.Unset)
			{
				String msg = String.Format("Object point coordinates:\nX: {0:00.00}\nY: {1:00.00}\nZ: {2:00.00}", readPoint.X, readPoint.Y, readPoint.Z);
				Dialogs.ShowMessage(msg, "Test User Data", ShowMessageButton.OK, ShowMessageIcon.Information);
				return Result.Success;
			}
			else
			{
				Dialogs.ShowMessage("Object contains no valid point coordinates!", "Test User Data", ShowMessageButton.OK, ShowMessageIcon.Warning);
				return Result.Failure;
			}
		}
	}
}
